@@ -15,8 +15,6 @@ from datetime import timedelta
 from os.path import join, dirname, isfile
 from os import makedirs, remove
 # non-standard imports
-from ecmwfapi import ECMWFDataServer
-from ecmwfapi.api import APIException
 from netCDF4 import Dataset
 from multiprocessing import Pool
 
@@ -25,7 +23,7 @@ __author__ = "Niklas Bohn, Andre Hollstein"
 
 """
 to install:
-pip install https://software.ecmwf.int/wiki/download/attachments/56664858/ecmwf-api-client-python.tgz
+pip install ecmwf-api-client
 documentation:
 https://software.ecmwf.int/wiki/display/WEBAPI/Accessing+ECMWF+data+servers+in+batch
 keyfile: needed in $HOME/.ecmwfapirc
@@ -653,6 +651,7 @@ class ECMWF_download(object):
 
 
 def test():
+    from ecmwfapi import ECMWFDataServer
     self = ECMWF_download(server=ECMWFDataServer(), max_step=24)
     if False:
         self.retrieve_grib(parameter="surface_pressure", year=2013, month=5, day_start=1, day_end=2,
@@ -744,6 +743,7 @@ class ECMWF_variable(object):
 
 
 def __download__(param):
+    from ecmwfapi.api import APIException
     # noinspection PyGlobalUndefined
     global download  # provided by initializer in multiprocessing mode
     try:
@@ -773,6 +773,7 @@ def download_variables(ecmwf_variables, db_path, date_from, date_to, db_path_fun
     """
 
     def initializer():
+        from ecmwfapi import ECMWFDataServer
         global download
         # make ECMWF instance for data download
         download = ECMWF_download(server=ECMWFDataServer(), max_step=max_step)
